@@ -6,7 +6,7 @@ The module also contains a constant :attr:`~integreat_cms.cms.constants.all_day.
 values linked to the strings and is used for correctly instantiating :class:`django.forms.TypedMultipleChoiceField`
 instances in :class:`~integreat_cms.cms.forms.events.event_filter_form.EventFilterForm`.
 """
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 
 #: This docstring is overridden by "alias of builtins.int"
