@@ -1,4 +1,4 @@
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 LINKCHECK_STATUS_TRANSLATIONS = [
     _("Broken external hash anchor"),
