@@ -1,7 +1,7 @@
 """
 This module contains the possible status of translations.
 """
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 
 #: Draft
