@@ -1,7 +1,7 @@
 """
 This module contains all constants representing the text directions of a :class:`~integreat_cms.cms.models.languages.language.Language`.
 """
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 
 #: Text is left to right, e.g. in English
