@@ -13,6 +13,8 @@ OUTDATED = "OUTDATED"
 FALLBACK = "FALLBACK"
 #: Missing
 MISSING = "MISSING"
+#: Machine translated
+MACHINE_TRANSLATED = "MACHINE_TRANSLATED"
 
 #: Choices to use these constants in a database field
 CHOICES = (
@@ -22,6 +24,7 @@ CHOICES = (
     # Do not show fallback translations in translation coverage
     # (FALLBACK, _("Default language is duplicated")),
     (MISSING, _("Translation missing")),
+    (MACHINE_TRANSLATED, _("Machine translated")),
 )
 
 #: Maps from the translation state to the color used to render this state in the translation coverage view
@@ -29,6 +32,7 @@ COLORS = {
     UP_TO_DATE: "#4ade80",
     IN_TRANSLATION: "#60a5fa",
     OUTDATED: "#facc15",
+    MACHINE_TRANSLATED: "#9933ff",
     # Do not show fallback translations in translation coverage
     # FALLBACK: "#60a5fa",
     MISSING: "#f87171",
