@@ -55,6 +55,7 @@ from .users.user_form import UserForm
 from .users.user_filter_form import UserFilterForm
 from .users.user_password_form import UserPasswordForm
 from .users.password_reset_form import CustomPasswordResetForm
+from .users.user_preferences_form import UserPreferencesForm
 
 from .object_search_form import ObjectSearchForm
 
@@ -62,3 +63,6 @@ from .poi_categories.poi_category_translation_form import (
     POICategoryTranslationForm,
     poi_category_translation_formset_factory,
 )
+
+from .translations.translations_management_form import TranslationsManagementForm
+from .poi_categories.poi_category_form import POICategoryForm
