@@ -2,7 +2,7 @@ import logging
 
 from django.db import models
 from django.utils.functional import cached_property
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 from ..abstract_content_model import AbstractContentModel
 
