@@ -3,6 +3,7 @@ This package contains views related to login, logout and password reset function
 """
 from .account_activation_view import AccountActivationView
 from .login_view import LoginView
+from .passwordless_login_view import PasswordlessLoginView
 from .logout_view import LogoutView
 from .password_reset_view import PasswordResetView
 from .password_reset_confirm_view import PasswordResetConfirmView
@@ -10,3 +11,5 @@ from .password_reset_confirm_view import PasswordResetConfirmView
 from .mfa.mfa_login_view import MfaLoginView
 from .mfa.mfa_assert_view import MfaAssertView
 from .mfa.mfa_verify_view import MfaVerifyView
+
+from .totp_login_view import TOTPLoginView
