@@ -1,5 +1,5 @@
 """
-This package contains custom middlewares, see :doc:`topics/http/middleware` and :doc:`ref/middleware`.
+This package contains custom middlewares, see :doc:`django:topics/http/middleware` and :doc:`django:ref/middleware`.
 """
 from .access_control_middleware import AccessControlMiddleware
 from .region_middleware import RegionMiddleware
